import base64
import os
import shutil
import subprocess

from charmhelpers import fetch
from charmhelpers.core import hookenv
from charmhelpers.core.host import adduser

from charmhelpers.payload.archive import extract_tarfile


# a list of debian packages to install:
REQUIRED_PACKAGES = ['python3', 'virtualenv']
SERVICE_DIR = '/srv/result-enum-worker'



def log_start(service_name):
    hookenv.log('result-enum-worker starting')


def install_packages(service_name):
    hookenv.log('Installing dependencies...')
    # fetch.add_source('ppa:canonical-ci-engineering/ci-airline-phase-0')
    fetch.configure_sources(update=True)
    fetch.apt_install(REQUIRED_PACKAGES, fatal=True)


def get_service_code_from_tarball(service_name):
    files_dir = os.path.join(hookenv.charm_dir(), 'files')
    tarball = os.path.join(files_dir, 'result-enum-worker.tgz')
    if not os.path.exists(SERVICE_DIR):
        hookenv.log('Installing the code for the first time from tarball')
        extract_tarfile(tarball, '/srv/')


def get_config_file(service_name):
    config = hookenv.config()
    config_content = base64.b64decode(config['config-file'])
    config_path = os.path.join(SERVICE_DIR, 'result-enum-worker.conf')
    with open(config_path, 'w') as f:
        f.write(config_content)


def create_user(service_name):
    adduser('result-enum-worker')


def install_python_packages(service_name):
    env_dir = os.path.join(SERVICE_DIR, 've')
    if os.path.exists(env_dir):
        hookenv.log('Service venv already exists, nothing to do ...')
        return

    hookenv.log('Installing python packages into the venv ...')
    hookenv.log(subprocess.check_output('which virtualenv'.split()))




    subprocess.check_call(['virtualenv', '-p', 'python3', env_dir])

    pip_cache = os.path.join(hookenv.charm_dir(), 'files', 'pip-cache')
    requirements = os.path.join(SERVICE_DIR, 'requirements.txt')

    if not os.path.exists(requirements):
        hookenv.log("No requirements.txt file found, nothing to install")
        return

    hookenv.log('Installing from download cache.')
    subprocess.check_call(['%s/bin/pip' % env_dir,
                           'install',
                           '--no-index',
                           '--find-links={}'.format(pip_cache),
                           '-r', requirements])

    subprocess.check_call(['%s/bin/pip' % env_dir,
                           'install', '--no-deps', '-e', SERVICE_DIR])
